# tkt-Toolkit
****
## Version : 1.4.9
This Package is made and published by the Suprime LLC

Read more about the License in the ``license.txt`` file.
# Used packages:
****
* **pytube**
* **base64**
* **json**
* **requests**
* **socket**
* **speech_recognition**
* **cryptography**
* **gtts**
* **random**
* **string**
* **TikTokApi**
# Description:
****
**Suprime's tkt-Toolkit python package, is a wide collection of packages and scripts, bundled in to
one package. It is optimized for python 3.8, but it also works with python 3.9,3.7,3.6.
Not all of the scripts used are made by us.**
# Features:
****
* **Voice recognition using pyaudio and speech_recognition.**
####  
* **Translation using gooletrans.**
####
* **Cryptography using cryptography.**
####  
* Smaller features: **Weather-data**, **TextToSpeech**, **Get-ip**, **Calculator**
* ### There are features still in progress 
# Examples
****
**For some code Examples, please read the `examples.txt` file.**
# Contact:
****
**Our email support: suprime.sendings@gmail.com**
